@@ -10,7 +10,7 @@ def validate_file_exists(file_path):
         raise FileNotFoundError(f"Given input file {file_path} does not exists")
 
 
-def validate_mandatory_arg(mandatory_args):
+def validate_mandatory_args(mandatory_args):
     """
     Validates if all the arguments are specified for the processing. Throws an exception otherwise
     :param mandatory_args: list of argument values
